@@ -134,10 +134,9 @@ def json_compare(actual, expected, ignore_regex1=[TIMESTAMP_REGEX, INTEGER]):
     expected = json.load(open(expected, "r"))  # Sample dictionary to be validated
     differenceJson = dict_diff(actual, expected, ignore_regex=ignore_regex)
     result = bool(differenceJson)
+
     if result:
-        print("Diffs found:", result)
-    else:
-        print("No diff found!")
+        print("Diffs found : ", result)
     assert result is False
 
 
@@ -145,10 +144,9 @@ def json_compare_dictionary(actual, expected, ignore_regex1=[TIMESTAMP_REGEX, IN
     ignore_regex = '(?:% s)' % '|'.join((str(regex) for regex in ignore_regex1))
     differenceJson = dict_diff(actual, expected, ignore_regex=ignore_regex)
     result = bool(differenceJson)
+
     if result:
-        print("Diffs found:", result)
-    else:
-        print("No diff found!")
+        print("Diffs found : ", result)
     assert result is False
 
 
@@ -232,9 +230,9 @@ def json_compare_schema(actual, expected, ignore_regex=TIMESTAMP_REGEX):
     expected = json.load(open(expected, "r"))  # Sample dictionary to be validated
     differenceJson = schema_dict_diff(actual, expected, ignore_regex=TIMESTAMP_REGEX)
     result = bool(differenceJson)
+
     if result:
-        print("Diffs found:", result)
-    else:
-        print("No diff found!")
+        print("Diffs found : ", result)
+
     assert schema_dict_diff(actual, expected, ignore_regex=TIMESTAMP_REGEX) == {}
     assert result is False
