@@ -116,7 +116,8 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
             test_name = os.environ.get("PYTEST_CURRENT_TEST").split(":")[-1].split(" ")[0]
             flow_probe_payload = test_name[test_name.find("[") + 1:test_name.find("]")]
             invocation_parameters = {
-                "markers": test_name.replace("[" + flow_probe_payload + "]", "").replace("test_", "").replace("tests_", "").lower()
+                "markers": test_name.replace("[" + flow_probe_payload + "]", "").replace("test_", "").replace("tests_", "").lower(),
+                "host": os.environ.get("ENV", None)
             }
 
             flow_probe_name = (test_name.split(":")[0].split(".")[0].replace("tests_", "").replace("test_", "").replace("_", " ").title())
