@@ -1,12 +1,16 @@
 import json
 import logging
+import os
+
 import requests
 import pytest
 from FunctionalTests.FunctionalParam import FunctionalParam
+import curlify
 
 functionalParm = FunctionalParam()
 logger = logging.getLogger()
 logger.setLevel(logging.DEBUG)
+IS_LOG_CURL = bool(os.getenv('IS_LOG_CURL', False))
 
 try:
     from Config.Defaultheader import Defaultheader
@@ -68,8 +72,11 @@ class Utilities(object):
         if endPoint.find("ifi/151613") == -1 and get_stage() == "beta":
             endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
+        # print(curlify.to_curl(response.request))
         Utilities.response = response
-        logger.info(f"status code{response.status_code}")
+        if IS_LOG_CURL:
+            Utilities.log_curl_req(response)
+
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
         logger.info(response.json())
@@ -97,7 +104,9 @@ class Utilities(object):
             endPoint = endPoint.replace("ifi/151613", "fi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         Utilities.response = response
-        logger.info(f"status code{response.status_code}")
+        if IS_LOG_CURL:
+            Utilities.log_curl_req(response)
+
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
 
@@ -123,15 +132,16 @@ class Utilities(object):
             endPoint = endPoint.replace("ifi/151613", "ifi/1")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         Utilities.response = response
-        logger.info(f"status code{response.status_code}")
+        if IS_LOG_CURL:
+            Utilities.log_curl_req(response)
         try:
             assert response.status_code == expectedStatusCode, \
                 f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match"
             return response
         except:
             logger.error(response.headers)
-            pytest.fail(f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match and response is {response.json()}")
-
+            pytest.fail(
+                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match and response is {response.json()}")
 
     def check_user_authentication(self,
                                   endPoint,
@@ -149,7 +159,9 @@ class Utilities(object):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         Utilities.response = response
-        logger.info(f"status code{response.status_code}")
+        if IS_LOG_CURL:
+            Utilities.log_curl_req(response)
+
         assert response.status_code == expectedStatusCode, \
             "Expected and Actual status code did not match"
         logger.info(response.json())
@@ -182,15 +194,32 @@ class Utilities(object):
             endPoint = endPoint.replace("ifi/151613", "ifi/1")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         Utilities.response = response
-        logger.info(f"status code{response.status_code}")
-        # logger.info("--------CURL START---------")
-        # functionalParm.curl_request(response.request.url,requestMethod,headers,jsonPayload)
-        # logger.info("--------CURL END---------")
+        if IS_LOG_CURL:
+            Utilities.log_curl_req(response)
+
         try:
             assert response.status_code == expectedStatusCode, \
-                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match with failure reason"
+                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match with failure reason {response.json()}"
             return response
         except:
-            # logger.error(response.headers)
-            pytest.fail(f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match")
+            logger.error(response.headers)
+            pytest.fail(
+                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match and response is {response.json()}")
 
+    @staticmethod
+    def log_curl_req(response):
+        logger.info("----------CURLIFY START----------------")
+        logger.info("                                       ")
+        logger.info("***********REQUEST CURL****************")
+        logger.info("                                       ")
+        logger.info(curlify.to_curl(response.request))
+        logger.info("                                       ")
+        logger.info("***********RESPONSE MESSAGE************")
+        logger.info("                                       ")
+        logger.info(f"Response :{response.text}")
+        logger.info("                                       ")
+        logger.info("***************************************")
+        logger.info("***** Response Time is:" + str(response.elapsed.total_seconds()))
+        logger.info("----------CURLIFY ENDS-----------------")
+        logger.info("                                       ")
+        logger.info(f"status code{response.status_code}")
